@@ -33,7 +33,11 @@ class Pod(object):
 class PodFunctionTask(PythonFunctionTask[Pod]):
     def __init__(self, task_config: Pod, task_function: Callable, **kwargs):
         super(PodFunctionTask, self).__init__(
-            task_config=task_config, task_type="sidecar", task_function=task_function, task_type_version=1, **kwargs,
+            task_config=task_config,
+            task_type="sidecar",
+            task_function=task_function,
+            task_type_version=1,
+            **kwargs,
         )
 
     def get_custom(self, settings: SerializationSettings) -> Dict[str, Any]:
